package com.ruoyi.system.service;


import com.ruoyi.system.domain.KaoqinConfig;

import java.util.List;

/**
 * 考勤规则配置Service接口
 * 
 * @author boman
 * @date 2023-02-02
 */
public interface IKaoqinConfigService 
{
    /**
     * 查询考勤规则配置
     * 
     * @param kaoqinId 考勤规则配置主键
     * @return 考勤规则配置
     */
    public KaoqinConfig selectKaoqinConfigByKaoqinId(Long kaoqinId);

    /**
     * 查询考勤规则配置列表
     * 
     * @param kaoqinConfig 考勤规则配置
     * @return 考勤规则配置集合
     */
    public List<KaoqinConfig> selectKaoqinConfigList(KaoqinConfig kaoqinConfig);

    /**
     * 新增考勤规则配置
     * 
     * @param kaoqinConfig 考勤规则配置
     * @return 结果
     */
    public int insertKaoqinConfig(KaoqinConfig kaoqinConfig);

    /**
     * 修改考勤规则配置
     * 
     * @param kaoqinConfig 考勤规则配置
     * @return 结果
     */
    public int updateKaoqinConfig(KaoqinConfig kaoqinConfig);

    /**
     * 批量删除考勤规则配置
     * 
     * @param kaoqinIds 需要删除的考勤规则配置主键集合
     * @return 结果
     */
    public int deleteKaoqinConfigByKaoqinIds(Long[] kaoqinIds);

    /**
     * 删除考勤规则配置信息
     * 
     * @param kaoqinId 考勤规则配置主键
     * @return 结果
     */
    public int deleteKaoqinConfigByKaoqinId(Long kaoqinId);
}
